@@ -7,7 +7,7 @@ use warnings;
 
 use Exporter qw(import);
 
-our $VERSION = '2.21';
+our $VERSION = '2.22';
 our @EXPORT  = qw(purl_to_urls purl_components_normalize);
 
 sub purl_components_normalize {
@@ -467,12 +467,16 @@ sub _maven_urls {
 
     my $purl = shift;
 
-    my $namespace  = $purl->namespace;
-    my $name       = $purl->name;
-    my $version    = $purl->version;
-    my $qualifiers = $purl->qualifiers;
-    my $extension  = $qualifiers->{extension}      // 'jar';
-    my $repo_url   = $qualifiers->{repository_url} // 'repo1.maven.org/maven2';
+    my $namespace      = $purl->namespace;
+    my $name           = $purl->name;
+    my $version        = $purl->version;
+    my $qualifiers     = $purl->qualifiers;
+    my $extension      = $qualifiers->{extension}      // 'jar';
+    my $repository_url = $qualifiers->{repository_url} // 'https://repo.maven.apache.org/maven2';
+
+    if ($repository_url !~ /^(http|https):\/\//) {
+        $repository_url = 'https://' . $repository_url;
+    }
 
     if ($namespace && $name && $version) {
 
@@ -480,7 +484,7 @@ sub _maven_urls {
 
         return {
             repository => "https://mvnrepository.com/artifact/$namespace/$name/$version",
-            download   => "https://$repo_url/$ns_url/$name/$version/$name-$version.$extension"
+            download   => "$repository_url/$ns_url/$name/$version/$name-$version.$extension"
         };
 
     }
@@ -565,7 +569,7 @@ URI::PackageURL::Util - Utility for URI::PackageURL
 
   use URI::PackageURL::Util qw(purl_to_urls);
 
-  $urls = purl_to_urls('pkg:cpan/GDT/URI-PackageURL@2.20');
+  $urls = purl_to_urls('pkg:cpan/GDT/URI-PackageURL@2.22');
 
   $filename = basename($urls->{download});
   $ua->mirror($urls->{download}, "/tmp/$filename");
@@ -611,13 +615,13 @@ C<cpan>, C<docker>, C<gem>, C<github>, C<gitlab>, C<luarocks>, C<maven>, C<npm>,
 (*)  Only with B<version> component
 (**) Only if B<download_url> qualifier is provided
 
-  $urls = purl_to_urls('pkg:cpan/GDT/URI-PackageURL@2.20');
+  $urls = purl_to_urls('pkg:cpan/GDT/URI-PackageURL@2.22');
 
   print Dumper($urls);
 
   # $VAR1 = {
-  #           'repository' => 'https://metacpan.org/release/GDT/URI-PackageURL-2.20',
-  #           'download' => 'http://www.cpan.org/authors/id/G/GD/GDT/URI-PackageURL-2.20.tar.gz'
+  #           'repository' => 'https://metacpan.org/release/GDT/URI-PackageURL-2.22',
+  #           'download' => 'http://www.cpan.org/authors/id/G/GD/GDT/URI-PackageURL-2.22.tar.gz'
   #         };
 
 =back
